==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MDF_diff.h <==
/* $Date: 1997/10/07 06:52:11 $  $Author: kg $  $Revision: 1.7 $ */

/**************************************************************************/
/* FILE:             MDF_diff.h                                           */
/* Autor:            Andreas Kemper                                       */
/* Erstellt:         28/02/92                                             */
/* Letzte Aenderung: 15/09/93                                             */
/*                                                                        */
/* Headerfile fuer den internen Differenzierer.                           */
/**************************************************************************/

#ifndef __MDF_diff__
#define __MDF_diff__




/*** Globale Variablen ****************************************************/

extern S_Pointer MDFV_ASS_MEM_MAIN;


/*** Prototypen ***********************************************************/

void      MDF_init ( 		VOID );
void      MDF_exit ( 		VOID );
void      MDF_reset (            VOID );
S_Pointer MDF_eval_diff (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MDF_diff (		S_Pointer	 expr, 
				S_Pointer	 string,
				S_Pointer	 exec,
				S_Pointer	 *ass_mem );
S_Pointer MDF_power_minus_one (	S_Pointer	 s );

S_Pointer MDF_new_diff_call( S_Pointer expr,
                             S_Pointer string);

S_Pointer MDF_partial(S_Pointer call,
                      S_Pointer string, 
                      S_Pointer exec,
                      S_Pointer *ass_mem);

S_Pointer
MDF_kettenregel(S_Pointer expr, S_Pointer ableit, S_Pointer exec, S_Pointer *ass_mem);

S_Pointer
MDF_AbleitSpecial(S_Pointer expr, S_Pointer ableit, S_Pointer exec);

int MDF_IsIdentOrIndex(S_Pointer s);

#endif /* __MDF_diff__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MDF_diff.h <==
/* $Date: 1999/06/02 07:21:04 $  $Author: kg $  $Revision: 1.6 $ */

/**************************************************************************/
/* FILE:             MDF_diff.h                                           */
/* Autor:            Andreas Kemper                                       */
/* Erstellt:         28/02/92                                             */
/* Letzte Aenderung: 15/09/93                                             */
/*                                                                        */
/* Headerfile fuer den internen Differenzierer.                           */
/**************************************************************************/

#ifndef __MDF_diff__
#define __MDF_diff__




/* Globale Variablen ****************************************************/

MTR_DECL_LITERAL(MDFV_D_IDENT)
MTR_DECL_LITERAL(MDFV_ASS_DIFF)

/* Prototypen ***********************************************************/

void      MDF_init ( 		 );
void      MDF_exit ( 		 );
void      MDF_reset (             );
S_Pointer MDF_eval_diff (	S_Pointer	 s,
				long		 prev_func,
				long		 eval_type,
				S_Pointer	 exec );
S_Pointer MDF_diff (		S_Pointer	 expr,
				S_Pointer	 string,
				S_Pointer	 exec,
				S_Pointer	 *ass_mem );
S_Pointer MDF_power_minus_one (	S_Pointer	 s );

S_Pointer MDF_new_diff_call( S_Pointer expr,
                             S_Pointer string);

S_Pointer MDF_partial(S_Pointer call,
                      S_Pointer string,
                      S_Pointer exec,
                      S_Pointer *ass_mem);

S_Pointer
MDF_kettenregel(S_Pointer expr, S_Pointer ableit, S_Pointer exec, S_Pointer *ass_mem);

S_Pointer
MDF_AbleitSpecial(S_Pointer expr, S_Pointer ableit, S_Pointer exec);

int MDF_IsIdentOrIndex(S_Pointer s);

#endif /* __MDF_diff__ */
